@@ -35,6 +35,12 @@ class CaseInsensitiveDict(abcMutableMapping):
         """Return the underlying dict in lowercase."""
         return {k.lower(): v for k, v in self._data.items()}
 
+    def get_lower(self, lower_key: str) -> Any:
+        """Get a lower case key."""
+        if lower_key in self._case_map:
+            return self._data[self._case_map[lower_key]]
+        return None
+
     def replace(self, new_data: abcMapping) -> None:
         """Replace the underlying dict."""
         if isinstance(new_data, CaseInsensitiveDict):
